package org.testing.web;

import static com.jayway.restassured.RestAssured.expect;
import java.io.File;
import static org.hamcrest.Matchers.is;
import org.jboss.arquillian.container.test.api.Deployment;
import org.jboss.arquillian.testng.Arquillian;
import org.jboss.shrinkwrap.api.ShrinkWrap;
import org.jboss.shrinkwrap.api.spec.WebArchive;
import org.jboss.shrinkwrap.resolver.api.maven.Maven;
import org.testng.annotations.Test;

public class TroubleIT extends Arquillian {
    private static final File WEBAPP_SRC = new File("src/main/webapp");

    @Deployment
    public static WebArchive createDeployment() {
        File[] libraries = Maven.resolver()
            .loadPomFromFile("pom.xml")
            .importRuntimeDependencies()
            .resolve()
            //.using(new RejectDependenciesStrategy(false, "testing:test-weld"))
            .withTransitivity()
            .asFile();
        return ShrinkWrap.create(WebArchive.class, "ROOT.war")
            .addAsLibraries(libraries)
            .addPackages(true, "org.testing.web")
            .addAsManifestResource(new File(WEBAPP_SRC, "META-INF/context.xml"), "context.xml")
            .addAsWebInfResource(new File(WEBAPP_SRC, "WEB-INF/beans.xml"))
            .setWebXML(new File(WEBAPP_SRC, "WEB-INF/web.xml"));
    }

    @Test
    public void testTrouble() {
        expect().
            statusCode(is(200)).
            contentType(is("text/plain;charset=UTF-8")).
            body(is("Here comes trouble!\n")).
        when().
            get("http://localhost:8084/trouble");
    }

}
